@@ -10,12 +10,6 @@
 madlib.glm <- function (formula, data, family = "gaussian",
                         na.action = "na.omit", control = list(), ...)
 {
-    ## Only newer versions of MADlib are supported
-    idx <- .localVars$conn.id[.localVars$conn.id[,1] == conn.id(data), 2]
-    if (identical(.localVars$db[[idx]]$madlib.v, numeric(0)) ||
-        .madlib.version.number(conn.id(data)) < 0.6)
-        stop("MADlib error: Please use Madlib version newer than 0.5!")
-
     args <- control
     args$formula <- formula
     args$data <- data
@@ -57,29 +51,21 @@ madlib.glm <- function (formula, data, family = "gaussian",
         stop("madlib.lm cannot be used on the object ",
              deparse(substitute(data)))
 
-    msg.level <- .set.msg.level("panic", conn.id(data)) # suppress all messages
+    ## Only newer versions of MADlib are supported
+    .check.madlib.version(data)
+
+    ## suppress all messages
+    msg.level <- .set.msg.level("panic", conn.id(data))
     ## disable warning in R, RPostgreSQL
     ## prints some unnessary warning messages
     warn.r <- getOption("warn")
     options(warn = -1)
 
-    params <- .analyze.formula(formula, data)
-
-    ## create temp table for db.Rquery objects
-    is.tbl.source.temp <- FALSE
-    if (is(params$data, "db.Rquery"))
-    {
-        tbl.source <- .unique.string()
-        is.tbl.source.temp <- TRUE
-        data <- as.db.data.frame(params$data, tbl.source, is.temp = FALSE,
-                                 verbose = FALSE)
-    }
-
-    is.factor <- data@.is.factor
-    cols <- names(data)
-    params <- .analyze.formula(formula, data, params$data, refresh = TRUE,
-                               is.factor = is.factor, cols = cols,
-                               suffix = data@.factor.suffix)
+    analyzer <- .get.params(formula, data)
+    data <- analyzer$data
+    params <- analyzer$params
+    is.tbl.source.temp <- analyzer$is.tbl.source.temp
+    tbl.source <- analyzer$tbl.source
 
     ## dependent, independent and grouping strings
     if (is.null(params$grp.str))
@@ -98,16 +84,8 @@ madlib.glm <- function (formula, data, family = "gaussian",
                  grp, ", ", max_iter, ", '", method, "', ",
                  tolerance, ")", sep = "")
 
-    ## execute the logistic regression
-    res <- try(.db.getQuery(sql, conn.id), silent = TRUE)
-    if (is(res, .err.class))
-        stop("Could not run MADlib logistic regression !")
-
-    ## retreive result
-    res <- try(.db.getQuery(paste("select * from", tbl.output), conn.id),
-               silent = TRUE)
-    if (is(res, .err.class))
-        stop("Could not retreive MADlib logistic regression result !")
+    ## execute the logistic regression and get the result
+    res <- .get.res(sql, tbl.output, conn.id)
 
     ## drop temporary tables
     .db.removeTable(tbl.output, conn.id)
