@@ -5,19 +5,19 @@
 
 predict.lm.madlib <- function (object, newdata, ...)
 {
-    .predict(object, newdata, "linregr_predict")
+    .predict(object, newdata, "linregr_predict", "double precision", "float8")
 }
 
 ## ------------------------------------------------------------------------
 
 predict.logregr.madlib <- function (object, newdata, ...)
 {
-    .predict(object, newdata, "logregr_predict")
+    .predict(object, newdata, "logregr_predict", "boolean", "bool")
 }
 
 ## ------------------------------------------------------------------------
 
-.predict <- function (object, newdata, func.str)
+.predict <- function (object, newdata, func.str, data.type, udt.name)
 {
     if (!is(newdata, "db.obj"))
         stop("New data for prediction must be a db.obj!")
@@ -94,6 +94,17 @@ predict.logregr.madlib <- function (object, newdata, ...)
     sql <- paste("select ", expr, " as madlib_predict from ",
                  tbl, where.str, sort$str, sep = "")
 
+    if (length(object$dummy) != 0) {
+        for (i in seq_len(length(object$dummy))) {
+            sql <- gsub(paste("(\"", object$dummy[i], "\"|",
+                              object$dummy[i], ")", sep = ""),
+                        object$dummy.expr[i], sql)
+            expr <- gsub(paste("(\"", object$dummy[i], "\"|",
+                               object$dummy[i], ")", sep = ""),
+                         object$dummy.expr[i], expr)
+        }
+    }
+
     new("db.Rquery",
         .content = sql,
         .expr = expr,
@@ -102,10 +113,11 @@ predict.logregr.madlib <- function (object, newdata, ...)
         .conn.id = conn.id(newdata),
         .col.name = "madlib_predict",
         .key = character(0),
-        .col.data_type = "double precision",
-        .col.udt_name = "float8",
+        .col.data_type = data.type,
+        .col.udt_name = udt.name,
         .where = where,
         .is.factor = FALSE,
+        .factor.suffix = "",
         .sort = sort)
 }
 
