@@ -291,6 +291,10 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
                      paste(labels, collapse = ","),
                      "]", sep = "") # independent variable
 
+    dep.var <- .consistent.func(dep.var)
+    ind.var <- .consistent.func(ind.var)
+    labels <- .consistent.func(labels)
+    
     list(dep.str = dep.var, ind.str = ind.var, grp.str = grp,
          ind.vars = labels,
          has.intercept = as.logical(f.intercept),
@@ -299,6 +303,19 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
 
 ## ------------------------------------------------------------------------
 
+## R's log is SQL's log(exp(1.), x)
+## R's log10 is SQL's log
+.consistent.func <- function (strs)
+{
+    res <- gsub("log\\s*\\(", "ln(", strs)
+    res <- gsub("log10\\s*\\(", "log(", res)
+    ## res <- gsub("log2\\s*\\(", "log(2.,", res)
+    ## res <- gsub("logb\\s*\\(()", "log(", res)
+    res
+}
+
+## ------------------------------------------------------------------------
+
 .replace.with.quotes <- function (vars, cols)
 {
     n.order <- order(nchar(cols), decreasing = TRUE)
@@ -354,7 +371,7 @@ arraydb.to.arrayr <- function (str, type = "double", n = 1)
 {
     nlabels <- character(0)
     for (i in seq_len(length(labels))) {
-        if (labels[i] %in% names(data) && data@.col.data_type == "ARRAY") {
+        if (labels[i] %in% names(data) && data@.col.data_type == "array") {
             n <- .db.getQuery(paste("select array_upper(", labels[i], ",1) from ",
                               content(data), " limit 1", sep = ""), conn.id(data))[[1]]
             nlabels <- c(nlabels, paste(labels[i], "[", seq_len(n), "]", sep = ""))
